aboutsummaryrefslogtreecommitdiff
path: root/include/elf/dwarf.h
diff options
context:
space:
mode:
authorRichard Henderson <rth@redhat.com>1999-06-02 18:14:14 +0000
committerRichard Henderson <rth@redhat.com>1999-06-02 18:14:14 +0000
commit6e3db71c77df94e66d95a8e1931d7205ad407a9e (patch)
treec87fab218732f5c771fb1f53ffff07d3a4c1ce2f /include/elf/dwarf.h
parent6c8cb66eb122c58239702c01d075f1e28b730e0e (diff)
downloadfsf-binutils-gdb-6e3db71c77df94e66d95a8e1931d7205ad407a9e.zip
fsf-binutils-gdb-6e3db71c77df94e66d95a8e1931d7205ad407a9e.tar.gz
fsf-binutils-gdb-6e3db71c77df94e66d95a8e1931d7205ad407a9e.tar.bz2
Stu Grossman <grossman@babylon-5.cygnus.com>
* dwarf.h: Add LANG_JAVA. * dwarf2.h: Add DW_LANG_Java.
Diffstat (limited to 'include/elf/dwarf.h')
-rw-r--r--include/elf/dwarf.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/elf/dwarf.h b/include/elf/dwarf.h
index 4333d5e..1e72cd7 100644
--- a/include/elf/dwarf.h
+++ b/include/elf/dwarf.h
@@ -3,7 +3,7 @@
Written by Ron Guilmette (rfg@ncd.com)
-Copyright (C) 1992 Free Software Foundation, Inc.
+Copyright (C) 1992, 1999 Free Software Foundation, Inc.
This file is part of GNU CC.
@@ -301,7 +301,8 @@ enum dwarf_source_language {
/* GNU extensions */
- LANG_CHILL = 0x00009af3 /* random value for GNU Chill */
+ LANG_CHILL = 0x00009af3, /* random value for GNU Chill */
+ LANG_JAVA = 0x00009af4 /* random value + 1 for GNU Java */
};
#define LANG_lo_user 0x00008000 /* implementation-defined range start */